[Zope3-checkins] SVN: Zope3/trunk/src/zope/fssync/ Converted XXX to TODO.

Stephan Richter srichter at cosmos.phy.tufts.edu
Tue Jul 13 12:44:03 EDT 2004


Log message for revision 26462:
  Converted XXX to TODO.
  


Changed:
  U   Zope3/trunk/src/zope/fssync/fsmerger.py
  U   Zope3/trunk/src/zope/fssync/fssync.py
  U   Zope3/trunk/src/zope/fssync/merger.py
  U   Zope3/trunk/src/zope/fssync/metadata.py
  U   Zope3/trunk/src/zope/fssync/server/entryadapter.py
  U   Zope3/trunk/src/zope/fssync/tests/test_merger.py
  U   Zope3/trunk/src/zope/fssync/tests/test_network.py
  U   Zope3/trunk/src/zope/fssync/tests/test_snarf.py


-=-
Modified: Zope3/trunk/src/zope/fssync/fsmerger.py
===================================================================
--- Zope3/trunk/src/zope/fssync/fssync.py	2004-07-13 16:41:08 UTC (rev 26461)
+++ Zope3/trunk/src/zope/fssync/fssync.py	2004-07-13 16:44:02 UTC (rev 26462)
@@ -201,9 +201,9 @@
         text/html, HTML formatting is removed using a primitive
         formatter.
 
-        XXX This doesn't support proxies or redirect responses.
+        TODO: This doesn't support proxies or redirect responses.
         """
-        # XXX Don't change the case of the header names; httplib might
+        # TODO: Don't change the case of the header names; httplib might
         # not treat them in a properly case-insensitive manner.
         assert self.rooturl
         if not path.endswith("/"):
@@ -492,7 +492,7 @@
                 return
             shutil.copyfile(orig, target)
         elif isdir(target):
-            # XXX how to recurse?
+            # TODO: how to recurse?
             self.dirrevert(target)
         self.metadata.flush()
         if os.path.isdir(target):

Modified: Zope3/trunk/src/zope/fssync/merger.py
===================================================================
--- Zope3/trunk/src/zope/fssync/merger.py	2004-07-13 16:41:08 UTC (rev 26461)
+++ Zope3/trunk/src/zope/fssync/merger.py	2004-07-13 16:44:02 UTC (rev 26462)
@@ -150,7 +150,7 @@
         return None
 
     def merge_files_merge(self, local, original, remote):
-        # XXX This is platform dependent
+        # TODO: This is platform dependent
         if exists(original):
             origfile = original
         else:

Modified: Zope3/trunk/src/zope/fssync/metadata.py
===================================================================
--- Zope3/trunk/src/zope/fssync/metadata.py	2004-07-13 16:41:08 UTC (rev 26461)
+++ Zope3/trunk/src/zope/fssync/metadata.py	2004-07-13 16:44:02 UTC (rev 26462)
@@ -134,7 +134,7 @@
             return self.entries[name]
         if case_insensitive:
             # Look for a case-insensitive match -- expensive!
-            # XXX There's no test case for this code!
+            # TODO: There's no test case for this code!
             nbase = normcase(name)
             matches = [b for b in self.entries if normcase(b) == nbase]
             if matches:

Modified: Zope3/trunk/src/zope/fssync/server/entryadapter.py
===================================================================
--- Zope3/trunk/src/zope/fssync/server/entryadapter.py	2004-07-13 16:41:08 UTC (rev 26461)
+++ Zope3/trunk/src/zope/fssync/server/entryadapter.py	2004-07-13 16:44:02 UTC (rev 26462)
@@ -20,7 +20,7 @@
 from zope.interface import implements
 from zope.xmlpickle import toxml
 
-# XXX This is a bug; we shouldn't depend on these packages at all.
+# TODO: This is a bug; we shouldn't depend on these packages at all.
 # Need to restructure.
 from zope.proxy import removeAllProxies
 from zope.app.fssync import fspickle
@@ -88,7 +88,7 @@
     implements(IObjectFile)
 
     def __init__(self, context):
-        # XXX for now, remove all proxies.
+        # TODO: for now, remove all proxies.
         ObjectEntryAdapter.__init__(self, removeAllProxies(context))
 
     def getBody(self):

Modified: Zope3/trunk/src/zope/fssync/tests/test_merger.py
===================================================================
--- Zope3/trunk/src/zope/fssync/tests/test_merger.py	2004-07-13 16:41:08 UTC (rev 26461)
+++ Zope3/trunk/src/zope/fssync/tests/test_merger.py	2004-07-13 16:44:02 UTC (rev 26462)
@@ -199,7 +199,7 @@
         self.assertEqual((action, state), ("Nothing", "Conflict"))
         self.assertEqual(lentry.get("conflict"), mtime)
 
-    # XXX need test cases for anomalies, e.g. files missing or present
+    # TODO: need test cases for anomalies, e.g. files missing or present
     # in spite of metadata, or directories instead of files, etc.
 
 def test_suite():

Modified: Zope3/trunk/src/zope/fssync/tests/test_network.py
===================================================================
--- Zope3/trunk/src/zope/fssync/tests/test_network.py	2004-07-13 16:41:08 UTC (rev 26461)
+++ Zope3/trunk/src/zope/fssync/tests/test_network.py	2004-07-13 16:44:02 UTC (rev 26462)
@@ -119,7 +119,7 @@
         self.assertEqual(self.network.host_port, "host:8080")
 
     def test_findrooturl_notfound(self):
-        # XXX This test will fail if a file /tmp/@@Zope/Root exists :-(
+        # TODO: This test will fail if a file /tmp/@@Zope/Root exists :-(
         target = self.tempdir()
         self.assertEqual(self.network.findrooturl(target), None)
 

Modified: Zope3/trunk/src/zope/fssync/tests/test_snarf.py
===================================================================
--- Zope3/trunk/src/zope/fssync/tests/test_snarf.py	2004-07-13 16:41:08 UTC (rev 26461)
+++ Zope3/trunk/src/zope/fssync/tests/test_snarf.py	2004-07-13 16:44:02 UTC (rev 26462)
@@ -139,7 +139,7 @@
         self.assertRaises(IOError, snf.translatepath, "a/")
         self.assertRaises(IOError, snf.translatepath, "")
 
-    # XXX More to add...
+    # TODO: More to add...
 
 def test_suite():
     s = unittest.TestSuite()



More information about the Zope3-Checkins mailing list
--- Zope3/trunk/src/zope/fssync/fsmerger.py	2004-07-13 16:41:08 UTC (rev 26461)
+++ Zope3/trunk/src/zope/fssync/fsmerger.py	2004-07-13 16:44:02 UTC (rev 26462)
@@ -52,9 +52,9 @@
             self.merge_dirs(local, remote)
         else:
             # One is a file, the other is a directory
-            # XXX We should be able to deal with this case, too
-            self.reporter("XXX %s" % local)
-            # XXX probably for the best; we *don't* know the right
+            # TODO: We should be able to deal with this case, too
+            self.reporter("TODO: %s" % local)
+            # TODO: probably for the best; we *don't* know the right
             # thing to do anyway
             return
         flag = self.metadata.getentry(local).get("flag")
@@ -85,7 +85,7 @@
             if isdir(target):
                 shutil.rmtree(target)
             else:
-                # XXX when should this ever happen?
+                # When should this ever happen?
                 os.remove(target)
         # remove the specials directory only if it's empty
         if isdir(dir):
@@ -302,7 +302,7 @@
         self.reporter("%s %s" % (letter, local))
 
     def ignore(self, path):
         # XXX This should have a larger set of default patterns to
         # ignore, and honor .cvsignore
         fn = basename(path)
         return (fn.endswith("~")
@@ -302,7 +302,7 @@
 
     def ignore(self, path):
-        # XXX This should have a larger set of default patterns to
+        # TODO: This should have a larger set of default patterns to
         # ignore, and honor .cvsignore
         fn = basename(path)

Modified: Zope3/trunk/src/zope/fssync/fssync.py
===================================================================